@@ -2,7 +2,7 @@ __author__ = "Vanessa Sochat"
 __copyright__ = "Copyright 2021, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
-__version__ = "0.0.21"
+__version__ = "0.0.23"
 AUTHOR = "Vanessa Sochat"
 NAME = "singularity-hpc"
 PACKAGE_URL = "https://github.com/singularityhub/singularity-hpc"
@@ -20,16 +20,10 @@ INSTALL_REQUIRES = (
     ("Jinja2", {"min_version": None}),
     ("jsonschema", {"min_version": None}),
     ("ruamel.yaml", {"min_version": None}),
-    ("sqlalchemy", {"min_version": None}),
 )
 
 TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)
 
-################################################################################
-# Install basic without database (default)
-
-INSTALL_BASIC = INSTALL_REQUIRES[:-1]
-
 ################################################################################
 # Submodule Requirements (versions that include database)
 
